/*
 *-------------------------------------------------------------------
 *
 *   engineConfig.h -- basic engine configuration data
 *
 * This file has been created by John S. Gwynne for support of 
 * Motorola's 68332 MCU in the efi332 project.
 * 
 * Redistribution and use in source and binary forms are permitted
 * provided that the following conditions are met:
 * 1. Redistribution of source code and documentation must retain
 *    the above authorship, this list of conditions and the
 *    following disclaimer.
 * 2. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * This software is provided "AS IS" without warranty of any kind,
 * either expressed or implied, including, but not limited to, the
 * implied warranties of merchantability, title and fitness for a
 * particular purpose.
 *
 *------------------------------------------------------------------
 */

#ifndef _engineConfig_h_
#define _engineConfig_h_


/*
 * TPU channel configuration
 *
 * Notes:
 * (1) TPUinjector, TPUignition, and TPUtach channels can be in any 
 * order, but as a whole _must_ be sequential.
 */

/* 
 * TPUincludeSimualtor -- 1 enables the simulator on the tpu channel
 * TPUsimulator. A 0 disables the function.
 */
#define TPUincludeSimualtor 1
#define TPUsimulator 0

/*
 * TPUcrank -- the value specifies the tpu channel associated with
 * the engine crank sensor.
 */
#define TPUcrank 1

/*
 * numberInjectors -- indicates the number of tpu channels to be used
 * for this function. A zero will disable it.
 *
 * TPUinjFireOrder -- a comma separated list of tpu channels listed in
 * firing order for this function.
 */
#define numberInjectors 0
#define TPUinjFireOrder 2, 3, 4, 5, 6, 7, 8, 9

/*
 * numberIgnition -- indicates the number of tpu channels to be used
 * for this function. A zero will disable it.
 *
 * TPUignFireOrder -- a comma separated list of tpu channels listed in
 * firing order for this function.
 */
#define numberIgnition 0
#define TPUignFireOrder 10, 11, 12, 13

/*
 * tach function TBD
 */
#warning add something for the tach

/*
 * The following defines the PRAM initialization parameters
 */
#define PMMXconfig 0x4		/* detect rising edge */
#define PMMXwaitTeeth 30	/* teeth counted before sync hunt */
#define PMMXintTooth 0x7f
#define PMMXstartPeriod 5
#define PMMXnumberPeriods 20
#define PMMXratio 96
#define PMMXlinkStart 2
#define PMMXlinkCount (numberInjectors+numberIgnition)

/*
 * StallResetCount -- a tooth count delay between establishing
 * synchronization and transitioining into a running state.
 * This provides the delay needed for PMMX lONG_PERIOD to be
 * initialized.
 */
#define StallResetCount 35

/*
 * If the crank sensor malfunctions and an asynchronous engine shutdown
 * is needed, the follow values are used to delay the discharge of any
 * charged coils from the time when the injectors are shutdown. The goal
 * is to let the engine pump IgnShutDownTurns turns of air with the 
 * injectors turned off to clear the cylinders of fuel before an 
 * asynchronous spark fires. The delay is limited to IgnShutDownMaxDelay
 * to ensure the coils are not damaged.
 */
#define IgnShutDownTurns 8
#define IgnShutDownMaxDelay 500	/* milliseconds */

/*
 * fuelPumpRunSample set the RPM sample time while the engine is running.
 * A stopped engine is sampled faster at a time of fuelPumpStopSample.
 */
#define fuelPumpRunSample 2500
#define fuelPumpStopSample 50

/*
 * The time delay between monitor reports.
 */
#define monitorRate 5

#endif /* _engineConfig_h_ */
