/*
 *-------------------------------------------------------------------
 *
 *   fuelPump.c -- controls the fuel pump.
 *
 * This file has been created by John S. Gwynne for support of 
 * Motorola's 68332 MCU in the efi332 project.
 * 
 * Redistribution and use in source and binary forms are permitted
 * provided that the following conditions are met:
 * 1. Redistribution of source code and documentation must retain
 *    the above authorship, this list of conditions and the
 *    following disclaimer.
 * 2. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * This software is provided "AS IS" without warranty of any kind,
 * either expressed or implied, including, but not limited to, the
 * implied warranties of merchantability, title and fitness for a
 * particular purpose.
 *
 *------------------------------------------------------------------
 */

#include <stdio.h>
#include <string.h>
#include "system.h"
#include "engineConfig.h"
#include "logger.h"
#include "crank.h"
#include "global.h"


/* states */
#define running 0
#define stopped1 1
#define stopped2 2
#define stopped3 3
#define stopped4 4
#define stopped5 5
#define stopped6 6
#define stopped7 7


static void fuelPumpStart(void);
__inline__ static void fuelPumpStart(void) {
#warning add code to switch pump
    LOG(LOG_NOTICE,"fuelPump: fuel pump start",LogLineLength);
}

static void fuelPumpStop(void);
__inline__ static void fuelPumpStop(void) {
#warning add code to switch pump
    LOG(LOG_NOTICE,"fuelPump: fuel pump stop",LogLineLength);
}

rtems_task fuelPump(
  rtems_task_argument argument
  )
{
    rtems_id          tid;
    rtems_status_code status;

    static int state = running;
    int rpm;
    int sleepTime = fuelPumpRunSample;	/* mSec */

    status = rtems_task_ident( RTEMS_SELF, RTEMS_SEARCH_ALL_NODES, &tid );
    directive_failed( status, "rtems_task_ident" );

    fuelPumpStart();

    while(FOREVER) {

	status = rtems_task_wake_after((sleepTime * TICKS_PER_SECOND) / 1000);
	directive_failed( status, "rtems_task_wake_after" );

	rpm = engineRPM();
	switch(state) {
	case running:
	    sleepTime = fuelPumpRunSample;
	    if ( engineState() == crankStalled)
		state++;
	    break;
	case stopped1:
	case stopped2:
	case stopped3:
	case stopped4:
	case stopped5:
	    sleepTime = fuelPumpRunSample;
	    if ( engineState() == crankStalled)
		state++;
	    else
		state = running;
	    break;
	case stopped6:
	    sleepTime = fuelPumpStopSample;
	    fuelPumpStop();
	    state++;
	    break;
	case stopped7:
	    sleepTime = fuelPumpStopSample;
	    if ( engineState() != crankStalled) {
		state = running;
		fuelPumpStart();
	    }
	    break;
	}
    }
}
