/*
 *-------------------------------------------------------------------
 *
 *   global.h -- basic engine related parameters available to all
 *   non-driver functions
 *
 * This file has been created by John S. Gwynne for support of 
 * Motorola's 68332 MCU in the efi332 project.
 * 
 * Redistribution and use in source and binary forms are permitted
 * provided that the following conditions are met:
 * 1. Redistribution of source code and documentation must retain
 *    the above authorship, this list of conditions and the
 *    following disclaimer.
 * 2. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * This software is provided "AS IS" without warranty of any kind,
 * either expressed or implied, including, but not limited to, the
 * implied warranties of merchantability, title and fitness for a
 * particular purpose.
 *
 *------------------------------------------------------------------
 */

#ifndef _global_h_
#define _global_h_

#include "crank.h"
#include "tpudriver.h"


/*
 * crankState -- indicates the following engine states:
 *    crankStalled -- engine not not turning.
 *    crankTransitioning -- engine crank sensor synchronized; waiting for
 *       accumulated period to become valid.
 *    crankRunning -- engine is turning and crank sensor is synchronized.
 */  
static int engineState(void);
__inline__ static int engineState(void) {
    return crankState;
}


/*
 * crankRPM -- returns the current crank speed in RPM
 */
static int engineRPM();
__inline__ static int engineRPM() {
    int speed;
    if (engineState() == crankRunning) {
	rtems_status_code status;
	speed = TPUengineRPM;
	status = rtems_io_read(DevMajorTPU,DevMinorCrank,&speed);
	directive_failed( status, "rtems_io_close" );
	if (speed <= PMMXlp2RPM(0xffff) ) {
	    speed = TPUengineSinglePeriodRPM;
	    status = rtems_io_read(DevMajorTPU,DevMinorCrank,&speed);
	    directive_failed( status, "rtems_io_close" );
	}
    } else
	speed = 0;
    return speed;
}


#endif /* _global_h_ */
