/*
 *-------------------------------------------------------------------
 *
 *   crankInline.h -- inline function definitions for crank.c
 *
 * This file has been created by John S. Gwynne for support of 
 * Motorola's 68332 MCU in the efi332 project.
 * 
 * Redistribution and use in source and binary forms are permitted
 * provided that the following conditions are met:
 * 1. Redistribution of source code and documentation must retain
 *    the above authorship, this list of conditions and the
 *    following disclaimer.
 * 2. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * This software is provided "AS IS" without warranty of any kind,
 * either expressed or implied, including, but not limited to, the
 * implied warranties of merchantability, title and fitness for a
 * particular purpose.
 *
 *------------------------------------------------------------------
 */

#ifndef _crankInline_h_
#define _crankInline_h_

#include "tpudriver.h"

static void crankStartSensorChannel(void);
__inline__ static void crankStartSensorChannel(void) {
    rtems_status_code status;
    status = rtems_io_open(DevMajorTPU,DevMinorCrank,NULL);
    directive_failed( status, "rtems_io_open" );
}

static int crankBlockForStatChange(void);
__inline__ static int crankBlockForStatChange(void){
    rtems_status_code status;
    int cmd[]={TPUstatusNumber};
    status = rtems_io_control(DevMajorTPU,DevMinorCrank,cmd);
    directive_failed( status, "rtems_io_control" );
    return *cmd;
}

static void crankSetToothInterrupt(int angle);
__inline__ static void crankSetToothInterrupt(int angle){
    rtems_status_code status;
    int cmd[]={TPUSetToothInterrupt, angle};
    status = rtems_io_control(DevMajorTPU,DevMinorCrank,cmd);
    directive_failed( status, "rtems_io_control" );
}

static void crankDisableToothInterrupt(void);
__inline__ static void crankDisableToothInterrupt(void){
    crankSetToothInterrupt(0x7f);
}

static void crankEnableAllChannels(void);
__inline__ static void crankEnableAllChannels(void) {
    rtems_status_code status;
    status = rtems_io_open(DevMajorTPU,DevMinorIgnition,NULL);
    directive_failed( status, "rtems_io_open" );
    status = rtems_io_open(DevMajorTPU,DevMinorInjector,NULL);
    directive_failed( status, "rtems_io_open" );
}

static void crankRestartTPU(int RPM);
__inline__ static void crankRestartTPU(int RPM){
    rtems_status_code status;
    int sleepTime;
    if (RPM) {
	sleepTime = IgnShutDownTurns*60*1000/RPM;
	if (sleepTime>IgnShutDownMaxDelay) sleepTime=IgnShutDownMaxDelay;
    } else
	sleepTime = IgnShutDownMaxDelay;
    status = rtems_io_close(DevMajorTPU,DevMinorCrank,&sleepTime);
    directive_failed( status, "rtems_io_close" );
    crankStartSensorChannel();
}

#endif /* _crankInline_h_ */
