/*
 *-------------------------------------------------------------------
 *
 *   logger.h -- defines for logger.c
 *
 * This file has been created by John S. Gwynne for support of 
 * Motorola's 68332 MCU in the efi332 project.
 * 
 * Redistribution and use in source and binary forms are permitted
 * provided that the following conditions are met:
 * 1. Redistribution of source code and documentation must retain
 *    the above authorship, this list of conditions and the
 *    following disclaimer.
 * 2. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * This software is provided "AS IS" without warranty of any kind,
 * either expressed or implied, including, but not limited to, the
 * implied warranties of merchantability, title and fitness for a
 * particular purpose.
 *
 *------------------------------------------------------------------
 */

#ifndef _Logger_h
#define _Logger_h

/* To disable the Logging function, uncomment the following */
/* #define InhibitLog */


/* To prevent a directive_failed during a LOG() call, uncomment 
   the following */
/* #define DoNotFailLog */


/* The following are defined to control the amount of logged
   information. LOG_DEBUG displays the most; LOG_ERROR the least. */
#define LOG_ERROR   1
#define LOG_WARNING 2
#define LOG_NOTICE  3
#define LOG_INFO    4
#define LOG_DEBUG   5


/* CurrentLogLevel stores the above log levels */
extern int CurrentLogLevel;

/*
 * LOG is an inline function that posts log measages through the
 * logging task. The form of the call is
 *
 * void LOG(int logLevel, char *message, int lengthMessage);
 *
 * where,
 *    logLevel is
 *    {LOG_ERROR,LOG_WARNING,LOG_NOTICE,LOG_INFO,LOG_DEBUG}.
 *
 *    message is the string logged.
 *
 *    lengthMessage is the size of meassage including the terminating NULL.
 */

#ifdef InhibitLog
#define LOG(a,b,c)
#else
static void LOG(int logLevel, char *message, int lengthMessage);
__inline__ static void LOG(int logLevel, char *message, int
			   lengthMessage) {
    rtems_status_code status;

    if (logLevel<=CurrentLogLevel) {
	status = rtems_message_queue_send( Queue_id[ LogQueueID ],
           message,lengthMessage);
#ifndef DoNotFailLog
	directive_failed( status, "rtems_message_queue_send" );
#endif /* DoNotFailLog */
    }
}
#endif /* InhibitLog */

#endif /* !_Logger_h */
