/*
 *-------------------------------------------------------------------
 *
 *   system.h -- executive task and message queue information
 *
 * This file has been created by John S. Gwynne for support of 
 * Motorola's 68332 MCU in the efi332 project.
 * 
 * Redistribution and use in source and binary forms are permitted
 * provided that the following conditions are met:
 * 1. Redistribution of source code and documentation must retain
 *    the above authorship, this list of conditions and the
 *    following disclaimer.
 * 2. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * This software is provided "AS IS" without warranty of any kind,
 * either expressed or implied, including, but not limited to, the
 * implied warranties of merchantability, title and fitness for a
 * particular purpose.
 *
 *------------------------------------------------------------------
 */

#ifndef _system_h_
#define _system_h_

#include <tmacros.h>

/* function prototypes */

rtems_task Init(
  rtems_task_argument argument
);

rtems_task TestLoop(
  rtems_task_argument argument
);

rtems_task logger(
  rtems_task_argument argument
);

rtems_task crankSenor(
  rtems_task_argument argument
);

rtems_task fuelPump(
  rtems_task_argument argument
);

rtems_task monitor(
  rtems_task_argument argument
);

rtems_device_driver tpu_initialize( 
  rtems_device_major_number  major,
  rtems_device_minor_number  minor,
  void                      *argument
  );

rtems_device_driver tpu_open( 
  rtems_device_major_number  major,
  rtems_device_minor_number  minor,
  void                      *argument
  );

rtems_device_driver tpu_close( 
  rtems_device_major_number  major,
  rtems_device_minor_number  minor,
  void                      *argument
  );

rtems_device_driver tpu_control( 
  rtems_device_major_number  major,
  rtems_device_minor_number  minor,
  void                      *argument
  );

rtems_device_driver tpu_read( 
  rtems_device_major_number  major,
  rtems_device_minor_number  minor,
  void                      *argument
  );

/* configuration information */

#define CONFIGURE_SPTEST

#define CONFIGURE_HAS_OWN_DEVICE_DRIVER_TABLE

#define NULL_DRIVER_TABLE_ENTRY \
 { NULL, NULL, NULL, NULL, NULL, NULL }

#define TPU_DRIVER_TABLE_ENTRY \
{ tpu_initialize, tpu_open,  tpu_close, \
      tpu_read, NULL, tpu_control }

#include <timerdrv.h>
#include <stubdrv.h>

#define DevMajorTPU 2

#ifdef CONFIGURE_INIT
rtems_driver_address_table Device_drivers[] = {
  CONSOLE_DRIVER_TABLE_ENTRY,
  CLOCK_DRIVER_TABLE_ENTRY,
  TPU_DRIVER_TABLE_ENTRY,
  NULL_DRIVER_TABLE_ENTRY
};
#endif /* CONFIGURE_INIT */

#define CONFIGURE_MAXIMUM_MESSAGE_QUEUES     10

#include <confdefs.h>

/* other defines */

#define LogQueueID 1
#define LogLineLength 50
#define TPUQueueID 2
#define TPUQueueLength sizeof(int)

#define crankSenorPriority 20
#define fuelPumpPriority 50
#define monitorPriority 100
#define LogTaskPriority 200
#define TestLoopPriority 254

/* global variables */

TEST_EXTERN rtems_id   Task_id[ 6 ];         /* array of task ids */
TEST_EXTERN rtems_name Task_name[ 6 ];       /* array of task names */

TEST_EXTERN rtems_id   Queue_id[ 3 ];        /* array of queue ids */
TEST_EXTERN rtems_name Queue_name[ 3 ];      /* array of queue names */

#endif /* _system_h_ */
