#ifndef _tpudriver_h_
#define _tpudriver_h_

#include "tpu.h"

/* clock parameters */
#define TPUDivBy 32
#define TPUPSCK 0
#define TPUTCR1 0

#define PMMXlongPeriod ( (unsigned int)(*(TPU_PR0+TPUcrank*8+0)) )
#define PMMXsingleToothPeriod ( (unsigned int)(*(TPU_PR0+15*8+6)) )
#define TPU_RAM_SIZE (2*1024)
#define TRAM_START 0xf0000
#define EFI_TPU_IARB 13
#define EFI_TPU_CIRL 5
#define EFI_TPU_CIBV (96 >> 4)	/* Vectors 96-111 */
#define EFI_TPU0 96
#define EFI_TPU1 97
#define EFI_TPU2 98
#define EFI_TPU3 99
#define EFI_TPU4 100
#define EFI_TPU5 101
#define EFI_TPU6 102
#define EFI_TPU7 103
#define EFI_TPU8 104
#define EFI_TPU9 105
#define EFI_TPU10 106
#define EFI_TPU11 107
#define EFI_TPU12 108
#define EFI_TPU13 109
#define EFI_TPU14 110
#define EFI_TPU15 111

/* channel priorities */
#define crankPriority TPU_High
#define ignitionPriority TPU_Middle
#define injectorPriority TPU_Middle
#define simulatorPriority TPU_Low

/* Minor device numbers */
#define DevMinorCrank 0
#define DevMinorIgnition 1
#define DevMinorInjector 2
#define DevMinorSimulator 3

/* I/O control operations */
#define TPUstatusNumber 1
#define TPUSetToothInterrupt 2

/* read operations */
#define TPUengineRPM 0
#define TPUengineSinglePeriodRPM 1

/* status number definitions */
#define crankToothInterrupt 0x00
#define crankSynchronize 0x01
#define crankInsufficientTransitions 0x81
#define crankGapUnexpectedTransition 0x82
#define crankUnexpectedTransition 0x83
#define crankMissedTooth 0x84
#define crankExcesiveTimeOut 0x85


#define PMMXlp2RPM(a) (((unsigned int)(SYS_CLOCK)/TPUDivBy* \
   PMMXnumberPeriods)/a)
#define PMMXsp2RPM(a) (((int)(SYS_CLOCK)/TPUDivBy)/a)


rtems_isr crankISR(rtems_vector_number vector);
rtems_isr ignitionISR(rtems_vector_number vector);
rtems_isr injectorISR(rtems_vector_number vector);
rtems_isr simulatorISR(rtems_vector_number vector);

#warning this should be removed
extern unsigned int tpuSimPeriod;

#endif /* _tpudriver_h_ */
