/*
 *-------------------------------------------------------------------
 *
 *   init.c -- RTEMS initialization program
 *
 * This file has been created by John S. Gwynne for support of 
 * Motorola's 68332 MCU in the efi332 project.
 * 
 * Redistribution and use in source and binary forms are permitted
 * provided that the following conditions are met:
 * 1. Redistribution of source code and documentation must retain
 *    the above authorship, this list of conditions and the
 *    following disclaimer.
 * 2. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * This software is provided "AS IS" without warranty of any kind,
 * either expressed or implied, including, but not limited to, the
 * implied warranties of merchantability, title and fitness for a
 * particular purpose.
 *
 *------------------------------------------------------------------
 */

#define TEST_INIT
#include "system.h"
#include "logger.h"

rtems_task Init(
  rtems_task_argument argument
)
{
  rtems_status_code status;
  rtems_time_of_day time;

  puts( "\n\n*** Wheel Test ***" );

  build_time( &time, 12, 31, 1988, 0, 0, 0, 0 );
  status = rtems_clock_set( &time );
  directive_failed( status, "rtems_clock_set" );

  Task_name[ 1 ] = rtems_build_name( 'T', 'A', '1', ' ' );
  Task_name[ 2 ] = rtems_build_name( 'L', 'O', 'G', ' ' );
  Task_name[ 3 ] = rtems_build_name( 'C', 'R', 'K', ' ' );
  Task_name[ 4 ] = rtems_build_name( 'F', 'P', 'C', ' ' );
  Task_name[ 5 ] = rtems_build_name( 'M', 'O', 'N', ' ' );

  status = rtems_task_create(
     Task_name[ 1 ],
     TestLoopPriority,
     RTEMS_MINIMUM_STACK_SIZE,
     RTEMS_PREEMPT|RTEMS_NO_TIMESLICE|RTEMS_NO_ASR|RTEMS_INTERRUPT_LEVEL(0),
     RTEMS_DEFAULT_ATTRIBUTES,
     &Task_id[ 1 ]
  );
  directive_failed( status, "rtems_task_create of TA1" );

  status = rtems_task_create(
     Task_name[ 2 ],
     LogTaskPriority,
     RTEMS_MINIMUM_STACK_SIZE,
     RTEMS_PREEMPT|RTEMS_NO_TIMESLICE|RTEMS_NO_ASR|RTEMS_INTERRUPT_LEVEL(0),
     RTEMS_DEFAULT_ATTRIBUTES,
     &Task_id[ 2 ]
  );
  directive_failed( status, "rtems_task_create of LOG" );

  status = rtems_task_create(
     Task_name[ 3 ],
     crankSenorPriority,
     RTEMS_MINIMUM_STACK_SIZE,
     RTEMS_PREEMPT|RTEMS_NO_TIMESLICE|RTEMS_NO_ASR|RTEMS_INTERRUPT_LEVEL(0),
     RTEMS_DEFAULT_ATTRIBUTES,
     &Task_id[ 3 ]
  );
  directive_failed( status, "rtems_task_create of CRK" );

  status = rtems_task_create(
     Task_name[ 4 ],
     fuelPumpPriority,
     RTEMS_MINIMUM_STACK_SIZE,
     RTEMS_PREEMPT|RTEMS_NO_TIMESLICE|RTEMS_NO_ASR|RTEMS_INTERRUPT_LEVEL(0),
     RTEMS_DEFAULT_ATTRIBUTES,
     &Task_id[ 4 ]
  );
  directive_failed( status, "rtems_task_create of FPC" );

  status = rtems_task_create(
     Task_name[ 5 ],
     monitorPriority,
     RTEMS_MINIMUM_STACK_SIZE,
     RTEMS_PREEMPT|RTEMS_NO_TIMESLICE|RTEMS_NO_ASR|RTEMS_INTERRUPT_LEVEL(0),
     RTEMS_DEFAULT_ATTRIBUTES,
     &Task_id[ 5 ]
  );
  directive_failed( status, "rtems_task_create of MON" );

  status = rtems_task_start( Task_id[ 1 ], TestLoop, 0 );
  directive_failed( status, "rtems_task_start of TA1" );

  status = rtems_task_start( Task_id[ 2 ], logger, 0 );
  directive_failed( status, "rtems_task_start of Log" );

  status = rtems_task_start( Task_id[ 3 ], crankSenor, 0 );
  directive_failed( status, "rtems_task_start of CRK" );

  status = rtems_task_start( Task_id[ 4 ], fuelPump, 0 );
  directive_failed( status, "rtems_task_start of FPC" );

  status = rtems_task_start( Task_id[ 5 ], monitor, 0 );
  directive_failed( status, "rtems_task_start of MON" );

  Queue_name[ LogQueueID ] = rtems_build_name( 'L', 'O', 'G', ' ' );
  Queue_name[ TPUQueueID ] = rtems_build_name( 'T', 'P', 'U', ' ' );

  status = rtems_message_queue_create(
     Queue_name[ LogQueueID ],
     100,
     LogLineLength+1,
     RTEMS_DEFAULT_ATTRIBUTES,
     &Queue_id[ LogQueueID ]
   );
  directive_failed( status, "rtems_message_queue_create of LOG" );

  status = rtems_message_queue_create(
     Queue_name[ TPUQueueID ],
     10,
     TPUQueueLength,
     RTEMS_DEFAULT_ATTRIBUTES,
     &Queue_id[ TPUQueueID ]
   );
  directive_failed( status, "rtems_message_queue_create of TPU" );

  LOG(LOG_NOTICE,"Starting Log",13);

  status = rtems_task_delete( RTEMS_SELF );
  directive_failed( status, "rtems_task_delete of RTEMS_SELF" );
}
