/*
 *-------------------------------------------------------------------
 *
 *   logger.c -- stdout message logging
 *
 * This file has been created by John S. Gwynne for support of 
 * Motorola's 68332 MCU in the efi332 project.
 * 
 * Redistribution and use in source and binary forms are permitted
 * provided that the following conditions are met:
 * 1. Redistribution of source code and documentation must retain
 *    the above authorship, this list of conditions and the
 *    following disclaimer.
 * 2. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * This software is provided "AS IS" without warranty of any kind,
 * either expressed or implied, including, but not limited to, the
 * implied warranties of merchantability, title and fitness for a
 * particular purpose.
 *
 *------------------------------------------------------------------
 */

#include <stdio.h>
#include "system.h"
#include "logger.h"

int CurrentLogLevel = LOG_DEBUG;

rtems_task logger(
  rtems_task_argument argument
  )
{
    rtems_id          tid;
    rtems_status_code status;
    rtems_time_of_day time;

    char s[LogLineLength+1];
    int length;
    int tickScale = (int) ( 1000.0/(float)TICKS_PER_SECOND);

    status = rtems_task_ident( RTEMS_SELF, RTEMS_SEARCH_ALL_NODES, &tid );
    directive_failed( status, "rtems_task_ident" );
    
    while( FOREVER ) {
	status = rtems_message_queue_receive(
	   Queue_id[ LogQueueID ],
	   s,
	   &length,
	   RTEMS_DEFAULT_OPTIONS,
	   RTEMS_NO_TIMEOUT
	);
	directive_failed( status, "rtems_message_queue_receive" );
	
	status = rtems_clock_get( RTEMS_CLOCK_GET_TOD, &time );
	directive_failed( status, "rtems_clock_get" );

	printf("%02d:%02d:%02d.%03d:: %s\n",time.hour,time.minute,
	   time.second,time.ticks*tickScale, s);
    }
}
