/*
 *-------------------------------------------------------------------
 *
 *   monitor.c -- periodically log engine parameter information
 *
 * This file has been created by John S. Gwynne for support of 
 * Motorola's 68332 MCU in the efi332 project.
 * 
 * Redistribution and use in source and binary forms are permitted
 * provided that the following conditions are met:
 * 1. Redistribution of source code and documentation must retain
 *    the above authorship, this list of conditions and the
 *    following disclaimer.
 * 2. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * This software is provided "AS IS" without warranty of any kind,
 * either expressed or implied, including, but not limited to, the
 * implied warranties of merchantability, title and fitness for a
 * particular purpose.
 *
 *------------------------------------------------------------------
 */

#include <stdio.h>
#include <string.h>
#include "system.h"
#include "engineConfig.h"
#include "logger.h"
#include "crank.h"
#include "global.h"


rtems_task monitor(
  rtems_task_argument argument
  )
{
    rtems_id          tid;
    rtems_status_code status;

    char s[LogLineLength];
    int rpm;

    status = rtems_task_ident( RTEMS_SELF, RTEMS_SEARCH_ALL_NODES, &tid );
    directive_failed( status, "rtems_task_ident" );

    while(FOREVER) {

	status = rtems_task_wake_after(monitorRate * TICKS_PER_SECOND);
	directive_failed( status, "rtems_task_wake_after" );

	rpm = engineRPM();

	if (rpm) {
	    sprintf(s,"monitor: rpm=%i",rpm);
	    LOG(LOG_NOTICE,s,strlen(s)+1);
	}
    }
}
